# -*- coding: utf-8 -*-

PLACE_HOLDER = '-'

DEFAULT_TOO_BUSY_ERROR_CODE = -1
DEFAULT_TOO_BUSY_EXC_NAME = 'TOO_BUSY_ERROR'
DEFAULT_TOO_BUSY_MSG = u"SOME THING TOO BUSY"

DEFAULT_BACKOFF_ERROR_CODE = -3
DEFAULT_BACKOFF_EXC_NAME = 'BACKOFF_ERROR'

SHIELDED_API_KEY = 'shielded_apis'
DEFAULT_STATSD = ""
